@@ -1034,9 +1034,7 @@ class InputWidget(gtk.HBox):
         self.scrollInput.get_vadjustment().connect('value-changed',
             self.move_sendbtn)
 
-        self.input.connect('copy-clipboard', self._on_copy_clipboard)
-        self.clipboard = gtk.Clipboard(selection=gtk.gdk.atom_intern("CLIPBOARD"))
-        self.input.get_buffer().add_selection_clipboard(self.clipboard)
+        self.input.connect_after('copy-clipboard', self._on_copy_clipboard)
 
         if setFocus:
             self.input.grab_focus()
@@ -1228,8 +1226,9 @@ class InputWidget(gtk.HBox):
         try:
             start_sel, end_sel = self.inputBuffer.get_selection_bounds()
             text = self.getInputText(False, True)
-            self.clipboard.set_text(text, len(text))
-            self.clipboard.store()
+            clipboard = gtk.clipboard_get()
+            clipboard.set_text(text, -1)
+            clipboard.store()
         except ValueError: #if the user just press ctrl+c with nothing selected
             return
 
