@@ -66,12 +66,14 @@ class UserPanel(gtk.HBox):
 
         self.mailButton = ImageButton(iconMail, '(0)')
         self.mailButton.set_relief(gtk.RELIEF_NONE)
+        self.mailButton.set_tooltip_text(_('Click here to access your mail'))
 
         i = self.controller.contacts.get_status()
         status = self.controller.status_ordered[0][i]
         self.statusIcon = self.theme.statusToPixbuf(status)
         self.statusButton = ImageButton(self.statusIcon)
         self.statusButton.set_relief(gtk.RELIEF_NONE)
+        self.statusButton.set_tooltip_text(_('Click here to change your status'))
 
         self.statusMenu = StatusMenu.StatusMenu(self.controller)
 
@@ -108,13 +110,14 @@ class UserPanel(gtk.HBox):
 
         self.bNick.set_tooltip_text(_('Click here to set your nick name'))
         self.bPersonalMessage.set_tooltip_text(_('Click here to set your personal message'))
-        self.bMedia.set_tooltip_text (_('Your current media'))
+        self.bMedia.set_tooltip_text(_('Your current media'))
 
         self.image = Widgets.avatarHolder(cellDimention = 48)
         self.imageEventBox = gtk.EventBox()
         self.imageEventBox.set_events(gtk.gdk.BUTTON_PRESS_MASK)
         self.imageEventBox.connect('button-press-event', self.avatarClicked)
         self.imageEventBox.add(self.image)
+        self.imageEventBox.set_tooltip_text(_('Click here to set your avatar'))
         #frame = gtk.AspectFrame()
         #frame.add(self.imageEventBox)
         if self.controller.avatar:
@@ -363,6 +366,12 @@ class UserPanel(gtk.HBox):
     def update_status_icon(self, msnp, status):
         self.statusButton.setIcon(self.theme.statusToPixbuf(status))
 
+    def hide_status_icon(self):
+        self.statusButton.hide()
+
+    def show_status_icon(self):
+        self.statusButton.show()
+
 class BaseImageButton:
     def __init__(self, icon, string=None):
         self.icon = icon
