@@ -20,6 +20,9 @@ import gobject
 import urllib
 import base64
 import os
+import httplib
+import socket
+import tempfile
 
 import ContactData
 import soap.manager
@@ -149,7 +152,10 @@ class ProfileManager(gobject.GObject):
 
         self.changeNick(nick, initial=True)
         self.changePersonalMessage(pm)
-        self.affinityCache = response.body.split('</CacheKey>')[0].split('<CacheKey>')[1]
+        try:
+            self.affinityCache = response.body.split('</CacheKey>')[0].split('<CacheKey>')[1]
+        except:
+            self.affinityCache = ''
         expression_profile = response.body.split('</ExpressionProfile>')[0].split('<ExpressionProfile>')[1]
         self.rid = expression_profile.split('</ResourceID>')[0].split('<ResourceID>')[1]
         self.profile_retrieved = True
@@ -165,9 +171,6 @@ class ProfileManager(gobject.GObject):
                     base64.b64encode(self.msnobj.data), self.onCreateRelationships)
 
     def getPicture(self, url):
-        import httplib
-        import socket
-        
         hdrs = {"User-Agent": "MSN Explorer/9.0 (MSN 8.0; TmstmpExt)",}
         
         if self.proxy and self.proxy.host != '':
@@ -208,16 +211,10 @@ class ProfileManager(gobject.GObject):
             return False
         data = response.read()
         #print "DP:", len(data), stat, reas
-        if os.name == "nt":
-            tempfolder = os.environ['TEMP'] + os.sep + "emsnpic"
-            tempfolder = unicode(tempfolder)
-        else:
-            tempfolder = '/tmp/emsnpic'
-        f = open(tempfolder, 'wb')
-        f.write(data)
-        f.close()
-        self.emit('self-dp-changed', tempfolder)
-
+        fd, fn = tempfile.mkstemp(prefix='emsnpic')
+        os.write(fd, data)
+        self.emit('self-dp-changed', fn)
+        
         return False
  
     def onSetDP(self, response):
