@@ -294,7 +294,7 @@ class Msnp(ProfileManager.ProfileManager):
             if self.proxy is None:
                 self.socket = Socket.Socket(host, port)
             else:
-                self.socket = Socket.PSocket(host, port, self.proxy)
+                self.socket = Socket.HTTPSocket(host, port, self.proxy)
 
         self.socket.connect('input', self._loginInputHandler)
         self.socket.connect('hangup', self._loginHangupHandler)
