@@ -37,12 +37,12 @@ except:
 class MainClass(Plugin.Plugin):
     '''Main plugin class'''
 
-    description = _('Notify about diferent events using the new notifications of Ubuntu')
+    description = _('Notifies various events using the new system notifications')
     authors = {'Mariano Guerra': 'luismarianoguerra at gmail dot com',
         'Nicolas Espina Tacchetti': 'nicolasespina at gmail dot com',
         'Panagiotis Koutsias': 'pkoutsias at gmail dot com',}
     website = 'http://emesene-msn.blogspot.com'
-    displayName = _('Notification')
+    displayName = _('NotifyOsdImproved')
     name = 'NotifyOsdImproved'
     require = ['pynotify']
     def __init__(self, controller, msn):
@@ -50,7 +50,7 @@ class MainClass(Plugin.Plugin):
 
         Plugin.Plugin.__init__(self, controller, msn)
 
-        self.description = _('Notify about diferent events using the new notifications of Ubuntu')
+        self.description = _('Notifies various events using the new system notifications')
         self.authors = {'Mariano Guerra': 'luismarianoguerra at gmail dot com',
         'Nicolas Espina Tacchetti': 'nicolasespina at gmail dot com',
         'Panagiotis Koutsias': 'pkoutsias at gmail dot com',}
@@ -74,14 +74,13 @@ class MainClass(Plugin.Plugin):
         self.showNotification = int(self.config.getPluginValue(self.name, 'showNotification', '0'))
 
         #Disable Notification on Systray
-        self.checkBox = gtk.CheckMenuItem(_('Disable Notifications'))
-        self.checkBox.set_active(self.showNotification)
-        self.checkBox.connect('activate', self.on_showNotification_activate)
-
-        self.tray = self.controller.trayIcon.getNotifyObject()
+        if not TrayIcon.disabled:
+            self.checkBox = gtk.CheckMenuItem(_('Disable Notifications'))
+            self.checkBox.set_active(self.showNotification)
+            self.checkBox.connect('activate', self.on_showNotification_activate)
+            self.tray = self.controller.trayIcon.getNotifyObject()
         self.pixbuf = self.controller.theme.getImage('userPanel')
 
-
         self.parser = controller.unifiedParser
         self.contacts = controller.contacts  # ref..
 
@@ -104,6 +103,12 @@ class MainClass(Plugin.Plugin):
     def on_showNotification_activate(self, *args):
         self.showNotification = self.checkBox.get_active()
         self.config.setPluginValue(self.name, 'showNotification', str(int(self.showNotification)))
+
+    def connect_onoff(self, *args):
+        self.onlineId = self.connect('user-online', self.online)
+        self.offlineId = self.connect('user-offline', self.offline)
+        if self.notifyId is not None: self.disconnect(self.notifyId)
+        self.notifyId = None
     
     def start(self):
         '''start the plugin'''
@@ -112,13 +117,18 @@ class MainClass(Plugin.Plugin):
         if not ERROR and not pynotify.init('emesene'):
             ERROR = _('there was a problem initializing the pynotify module')
 
-        self.onlineId = self.connect('user-online', self.online)
-        self.offlineId = self.connect('user-offline', self.offline)
+        self.notifyId = None
+        self.onlineId = None
+        self.offlineId = None
+        if self.msn.canNotify:
+            self.connect_onoff()
+        else:
+            self.notifyId = self.connect('enable-notifications', self.connect_onoff)
         self.newMsgId = self.connect('switchboard::message', self.newMsg)
         self.offMsgId = self.connect('offline-message-received', self.offMsg)
         self.typingId = self.connect('switchboard::typing', self.receiveTyping)
-        self.fTInviteId = self.msn.connect('new-file-transfer', self.notifyFileTransferInvite)
-        self.fTFinishedId = self.msn.connect('finished-file-transfer', self.notifyFileTransferFinished)
+        self.fTInviteId = self.connect('new-file-transfer', self.notifyFileTransferInvite)
+        self.fTFinishedId = self.connect('finished-file-transfer', self.notifyFileTransferFinished)
         self.newMailId = self.connect('new-mail-notification', self.newMail)
         self.initMailId = self.connect('initial-mail-notification', \
                 self.initMail)
@@ -135,8 +145,9 @@ class MainClass(Plugin.Plugin):
 
         self.notifications = []
 
-        self.disconnect(self.onlineId)
-        self.disconnect(self.offlineId)
+        if self.onlineId is not None: self.disconnect(self.onlineId)
+        if self.offlineId is not None: self.disconnect(self.offlineId)
+        if self.notifyId is not None: self.disconnect(self.notifyId)
         self.disconnect(self.newMsgId)
         self.disconnect(self.offMsgId)
         self.disconnect(self.typingId)
@@ -145,9 +156,10 @@ class MainClass(Plugin.Plugin):
         self.disconnect(self.newMailId)
         self.disconnect(self.initMailId)
         self.enabled = False
-        self.controller.trayIcon.menu.remove(self.checkBox);
-        self.controller.trayIcon.menu.show_all()
-        self.controller.trayIcon.update(self.controller.msn.status)
+        if not TrayIcon.disabled:
+            self.controller.trayIcon.menu.remove(self.checkBox);
+            self.controller.trayIcon.menu.show_all()
+            self.controller.trayIcon.update(self.controller.msn.status)
 
     def check(self):
         '''check if everything is OK to start the plugin
@@ -258,8 +270,6 @@ class MainClass(Plugin.Plugin):
 
     def notifyEnabled(self, contact = None):
         '''checks if notifications are enabled'''
-        if self.config.glob['disableTrayIcon']:
-            return False
         if not self.enabled:
             return False
         if self.notifyBusy and self.msn.status == 'BSY':
@@ -273,7 +283,7 @@ class MainClass(Plugin.Plugin):
 
     def notify(self, contact, title, text, execute = '', data = None):
 
-        notification = pynotify.Notification(title, text, attach = self.tray)
+        notification = pynotify.Notification(title, text)#, attach = self.tray)
         # both "append" and "x-canonical-append" work fine.
         notification.set_hint_string ("x-canonical-append", "allowed")
 
@@ -288,7 +298,7 @@ class MainClass(Plugin.Plugin):
             self.pixbuf = self.controller.theme.getImage('userPanel')
 
 
-        if self.controller.trayIcon and \
+        if not TrayIcon.disabled and \
            isinstance(self.controller.trayIcon.tray, gtk.StatusIcon):
             tray = self.controller.trayIcon.tray
             try:
